# ory_client.model.NormalizedProjectRevision

## Load the model package
```dart
import 'package:ory_client/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**createdAt** | [**DateTime**](DateTime.md) | The Project's Revision Creation Date | [optional] [readonly] 
**hydraOauth2ClientCredentialsDefaultGrantAllowedScope** | **bool** | Automatically grant authorized OAuth2 Scope in OAuth2 Client Credentials Flow.  Each OAuth2 Client is allowed to request a predefined OAuth2 Scope (for example `read write`). If this option is enabled, the full scope is automatically granted when performing the OAuth2 Client Credentials flow.  If disabled, the OAuth2 Client has to request the scope in the OAuth2 request by providing the `scope` query parameter.  Setting this option to true is common if you need compatibility with MITREid.  This governs the \"oauth2.client_credentials.default_grant_allowed_scope\" setting. | [optional] 
**hydraOauth2GrantJwtIatOptional** | **bool** | Configures if the issued at (`iat`) claim is required in the JSON Web Token (JWT) Profile for OAuth 2.0 Client Authentication and Authorization Grants (RFC7523).  If set to `false`, the `iat` claim is required. Set this value to `true` only after careful consideration.  This governs the \"oauth2.grant.jwt.iat_optional\" setting. | [optional] 
**hydraOauth2GrantJwtJtiOptional** | **bool** | Configures if the JSON Web Token ID (`jti`) claim is required in the JSON Web Token (JWT) Profile for OAuth 2.0 Client Authentication and Authorization Grants (RFC7523).  If set to `false`, the `jti` claim is required. Set this value to `true` only after careful consideration.  This governs the \"oauth2.grant.jwt.jti_optional\" setting. | [optional] 
**hydraOauth2GrantJwtMaxTtl** | **String** |  | [optional] 
**hydraOauth2PkceEnforced** | **bool** | Configures whether PKCE should be enforced for all OAuth2 Clients.  This governs the \"oauth2.pkce.enforced\" setting. | [optional] 
**hydraOauth2PkceEnforcedForPublicClients** | **bool** | Configures whether PKCE should be enforced for OAuth2 Clients without a client secret (public clients).  This governs the \"oauth2.pkce.enforced_for_public_clients\" setting. | [optional] 
**hydraOauth2RefreshTokenHook** | **String** | Sets the Refresh Token Hook Endpoint. If set this endpoint will be called during the OAuth2 Token Refresh grant update the OAuth2 Access Token claims.  This governs the \"oauth2.refresh_token_hook\" setting. | [optional] 
**hydraOauth2SessionAllowedTopLevelClaims** | **List<String>** |  | [optional] [default to const []]
**hydraOauth2SessionExcludeNotBeforeClaim** | **bool** | Set to true if you want to exclude claim `nbf (not before)` part of access token.  This governs the \"oauth2.session.exclude_not_before_claim\" setting. | [optional] 
**hydraOidcDynamicClientRegistrationDefaultScope** | **List<String>** |  | [optional] [default to const []]
**hydraOidcDynamicClientRegistrationEnabled** | **bool** | Configures OpenID Connect Dynamic Client Registration.  This governs the \"oidc.dynamic_client_registration.enabled\" setting. | [optional] 
**hydraOidcSubjectIdentifiersPairwiseSalt** | **String** | Configures OpenID Connect Discovery and overwrites the pairwise algorithm  This governs the \"oidc.subject_identifiers.pairwise_salt\" setting. | [optional] 
**hydraOidcSubjectIdentifiersSupportedTypes** | **List<String>** |  | [optional] [default to const []]
**hydraSecretsCookie** | **List<String>** |  | [optional] [default to const []]
**hydraSecretsSystem** | **List<String>** |  | [optional] [default to const []]
**hydraServeAdminCorsAllowedOrigins** | **List<String>** |  | [optional] [default to const []]
**hydraServeAdminCorsEnabled** | **bool** | Configures the Ory Hydra CORS Settings  This governs the \"serve.admin.cors.enabled\" setting. | [optional] 
**hydraServeCookiesSameSiteLegacyWorkaround** | **bool** | Configures the Ory Hydra Cookie Same Site Legacy Workaround  This governs the \"serve.cookies.same_site_legacy_workaround\" setting. | [optional] 
**hydraServeCookiesSameSiteMode** | **String** | Configures the Ory Hydra Cookie Same Site Mode  This governs the \"serve.cookies.same_site_mode\" setting. | [optional] 
**hydraServePublicCorsAllowedOrigins** | **List<String>** |  | [optional] [default to const []]
**hydraServePublicCorsEnabled** | **bool** | Configures the Ory Hydra CORS Settings  This governs the \"serve.public.cors.enabled\" setting. | [optional] 
**hydraStrategiesAccessToken** | [**Object**](.md) | Defines access token type. jwt is a bad idea, see https://www.ory.sh/docs/hydra/advanced#json-web-tokens  This governs the \"strategies.access_token\" setting. | [optional] 
**hydraStrategiesScope** | [**Object**](.md) | Defines how scopes are matched. For more details have a look at https://github.com/ory/fosite#scopes  This governs the \"strategies.scope\" setting. | [optional] 
**hydraTtlAccessToken** | **String** |  | [optional] 
**hydraTtlAuthCode** | **String** |  | [optional] 
**hydraTtlIdToken** | **String** |  | [optional] 
**hydraTtlLoginConsentRequest** | **String** |  | [optional] 
**hydraTtlRefreshToken** | **String** |  | [optional] 
**hydraUrlsConsent** | **String** | Sets the OAuth2 Consent Endpoint URL of the OAuth2 User Login & Consent flow.  Defaults to Ory Cloud's Managed UI if left empty.  This governs the \"urls.consent\" setting. | [optional] 
**hydraUrlsError** | **String** | Sets the OAuth2 Error URL of the OAuth2 User Login & Consent flow.  Defaults to Ory Cloud's Managed UI if left empty.  This governs the \"urls.error\" setting. | [optional] 
**hydraUrlsLogin** | **String** | Sets the OAuth2 Login Endpoint URL of the OAuth2 User Login & Consent flow.  Defaults to Ory Cloud's Managed UI if left empty.  This governs the \"urls.login\" setting. | [optional] 
**hydraUrlsLogout** | **String** | Sets the logout endpoint.  Defaults to Ory Cloud's Managed UI if left empty.  This governs the \"urls.logout\" setting. | [optional] 
**hydraUrlsPostLogoutRedirect** | **String** | When an OAuth2-related user agent requests to log out, they will be redirected to this url afterwards per default.  Defaults to Ory Cloud's Managed UI in development and your application in production mode when a custom domain is connected.  This governs the \"urls.post_logout_redirect\" setting. | [optional] 
**hydraUrlsSelfIssuer** | **String** | This value will be used as the issuer in access and ID tokens. It must be specified and using HTTPS protocol, unless the development mode is enabled.  In Ory Cloud it will be very rare that you want to modify this value. If left empty, it will default to the correct value for Ory Cloud.  This governs the \"urls.self.issuer\" setting. | [optional] 
**hydraWebfingerJwksBroadcastKeys** | **List<String>** |  | [optional] [default to const []]
**hydraWebfingerOidcDiscoveryAuthUrl** | **String** | Configures OpenID Connect Discovery and overwrites the OAuth2 Authorization URL.  This governs the \"webfinger.oidc.discovery.auth_url\" setting. | [optional] 
**hydraWebfingerOidcDiscoveryClientRegistrationUrl** | **String** | Configures OpenID Connect Discovery and overwrites the OpenID Connect Dynamic Client Registration Endpoint.  This governs the \"webfinger.oidc.discovery.client_registration_url\" setting. | [optional] 
**hydraWebfingerOidcDiscoveryJwksUrl** | **String** | Configures OpenID Connect Discovery and overwrites the JWKS URL.  This governs the \"webfinger.oidc.discovery.jwks_url\" setting. | [optional] 
**hydraWebfingerOidcDiscoverySupportedClaims** | **List<String>** |  | [optional] [default to const []]
**hydraWebfingerOidcDiscoverySupportedScope** | **List<String>** |  | [optional] [default to const []]
**hydraWebfingerOidcDiscoveryTokenUrl** | **String** | Configures OpenID Connect Discovery and overwrites the OAuth2 Token URL.  This governs the \"webfinger.oidc.discovery.token_url\" setting. | [optional] 
**hydraWebfingerOidcDiscoveryUserinfoUrl** | **String** | Configures OpenID Connect Discovery and overwrites userinfo endpoint to be advertised at the OpenID Connect Discovery endpoint /.well-known/openid-configuration. Defaults to Ory Hydra's userinfo endpoint at /userinfo. Set this value if you want to handle this endpoint yourself.  This governs the \"webfinger.oidc.discovery.userinfo_url\" setting. | [optional] 
**id** | **String** |  | [optional] 
**ketoNamespaces** | [**List<KetoNamespace>**](KetoNamespace.md) |  | [optional] [default to const []]
**ketoReadMaxDepth** | **int** |  | [optional] 
**kratosCookiesSameSite** | **String** | Configures the Ory Kratos Cookie SameSite Attribute  This governs the \"cookies.same_site\" setting. | [optional] 
**kratosCourierSmtpConnectionUri** | **String** | Configures the Ory Kratos SMTP Connection URI  This governs the \"courier.smtp.connection_uri\" setting. | [optional] 
**kratosCourierSmtpFromAddress** | **String** | Configures the Ory Kratos SMTP From Address  This governs the \"courier.smtp.from_address\" setting. | [optional] 
**kratosCourierSmtpFromName** | **String** | Configures the Ory Kratos SMTP From Name  This governs the \"courier.smtp.from_name\" setting. | [optional] 
**kratosCourierSmtpHeaders** | [**Object**](.md) | NullJSONRawMessage represents a json.RawMessage that works well with JSON, SQL, and Swagger and is NULLable- | [optional] 
**kratosCourierTemplatesRecoveryInvalidEmailBodyHtml** | **String** | Configures the Ory Kratos Invalid Recovery Email Body HTML Template  This governs the \"courier.smtp.templates.recovery.invalid.email.body.html\" setting. | [optional] 
**kratosCourierTemplatesRecoveryInvalidEmailBodyPlaintext** | **String** | Configures the Ory Kratos Invalid Recovery Email Body Plaintext Template  This governs the \"courier.smtp.templates.recovery.invalid.email.body.plaintext\" setting. | [optional] 
**kratosCourierTemplatesRecoveryInvalidEmailSubject** | **String** | Configures the Ory Kratos Invalid Recovery Email Subject Template  This governs the \"courier.smtp.templates.recovery.invalid.email.body.html\" setting. | [optional] 
**kratosCourierTemplatesRecoveryValidEmailBodyHtml** | **String** | Configures the Ory Kratos Valid Recovery Email Body HTML Template  This governs the \"courier.smtp.templates.recovery.valid.email.body.html\" setting. | [optional] 
**kratosCourierTemplatesRecoveryValidEmailBodyPlaintext** | **String** | Configures the Ory Kratos Valid Recovery Email Body Plaintext Template  This governs the \"courier.smtp.templates.recovery.valid.email.body.plaintext\" setting. | [optional] 
**kratosCourierTemplatesRecoveryValidEmailSubject** | **String** | Configures the Ory Kratos Valid Recovery Email Subject Template  This governs the \"courier.smtp.templates.recovery.valid.email.subject\" setting. | [optional] 
**kratosCourierTemplatesVerificationInvalidEmailBodyHtml** | **String** | Configures the Ory Kratos Invalid Verification Email Body HTML Template  This governs the \"courier.smtp.templates.verification.invalid.email.body.html\" setting. | [optional] 
**kratosCourierTemplatesVerificationInvalidEmailBodyPlaintext** | **String** | Configures the Ory Kratos Invalid Verification Email Body Plaintext Template  This governs the \"courier.smtp.templates.recovery.invalid.email.body.plaintext\" setting. | [optional] 
**kratosCourierTemplatesVerificationInvalidEmailSubject** | **String** | Configures the Ory Kratos Invalid Verification Email Subject Template  This governs the \"courier.smtp.templates.verification.invalid.email.subject\" setting. | [optional] 
**kratosCourierTemplatesVerificationValidEmailBodyHtml** | **String** | Configures the Ory Kratos Valid Verification Email Body HTML Template  This governs the \"courier.smtp.templates.verification.valid.email.body.html\" setting. | [optional] 
**kratosCourierTemplatesVerificationValidEmailBodyPlaintext** | **String** | Configures the Ory Kratos Valid Verification Email Body Plaintext Template  This governs the \"courier.smtp.templates.recovery.valid.email.body.plaintext\" setting. | [optional] 
**kratosCourierTemplatesVerificationValidEmailSubject** | **String** | Configures the Ory Kratos Valid Verification Email Subject Template  This governs the \"courier.smtp.templates.verification.valid.email.subject\" setting. | [optional] 
**kratosIdentitySchemas** | [**List<NormalizedProjectRevisionIdentitySchema>**](NormalizedProjectRevisionIdentitySchema.md) |  | [optional] [default to const []]
**kratosSecretsCipher** | **List<String>** |  | [optional] [default to const []]
**kratosSecretsCookie** | **List<String>** |  | [optional] [default to const []]
**kratosSecretsDefault** | **List<String>** |  | [optional] [default to const []]
**kratosSelfserviceAllowedReturnUrls** | **List<String>** |  | [optional] [default to const []]
**kratosSelfserviceDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Default Return URL  This governs the \"selfservice.allowed_return_urls\" setting. | [optional] 
**kratosSelfserviceFlowsErrorUiUrl** | **String** | Configures the Ory Kratos Error UI URL  This governs the \"selfservice.flows.error.ui_url\" setting. | [optional] 
**kratosSelfserviceFlowsHooks** | [**List<NormalizedProjectRevisionHook>**](NormalizedProjectRevisionHook.md) |  | [optional] [default to const []]
**kratosSelfserviceFlowsLoginAfterDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Login Default Return URL  This governs the \"selfservice.flows.login.after.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsLoginAfterOidcDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Login After OIDC Default Return URL  This governs the \"selfservice.flows.login.after.oidc.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsLoginAfterPasswordDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Login After Password Default Return URL  This governs the \"selfservice.flows.login.after.password.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsLoginAfterWebauthnDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Login After WebAuthn Default Return URL  This governs the \"selfservice.flows.login.after.webauthn.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsLoginLifespan** | **String** | Configures the Ory Kratos Login Lifespan  This governs the \"selfservice.flows.login.lifespan\" setting. | [optional] 
**kratosSelfserviceFlowsLoginUiUrl** | **String** | Configures the Ory Kratos Login UI URL  This governs the \"selfservice.flows.login.ui_url\" setting. | [optional] 
**kratosSelfserviceFlowsLogoutAfterDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Logout Default Return URL  This governs the \"selfservice.flows.logout.after.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsRecoveryAfterDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Recovery Default Return URL  This governs the \"selfservice.flows.recovery.after.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsRecoveryEnabled** | **bool** | Configures the Ory Kratos Recovery Enabled Setting  This governs the \"selfservice.flows.recovery.enabled\" setting. | [optional] 
**kratosSelfserviceFlowsRecoveryLifespan** | **String** | Configures the Ory Kratos Recovery Lifespan  This governs the \"selfservice.flows.recovery.lifespan\" setting. | [optional] 
**kratosSelfserviceFlowsRecoveryUiUrl** | **String** | Configures the Ory Kratos Recovery UI URL  This governs the \"selfservice.flows.recovery.ui_url\" setting. | [optional] 
**kratosSelfserviceFlowsRegistrationAfterDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Registration Default Return URL  This governs the \"selfservice.flows.registration.after.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsRegistrationAfterOidcDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Registration After OIDC Default Return URL  This governs the \"selfservice.flows.registration.after.oidc.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsRegistrationAfterPasswordDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Registration After Password Default Return URL  This governs the \"selfservice.flows.registration.after.password.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsRegistrationAfterWebauthnDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Registration After Password Default Return URL  This governs the \"selfservice.flows.registration.after.password.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsRegistrationEnabled** | **bool** |  | [optional] 
**kratosSelfserviceFlowsRegistrationLifespan** | **String** | Configures the Ory Kratos Registration Lifespan  This governs the \"selfservice.flows.registration.lifespan\" setting. | [optional] 
**kratosSelfserviceFlowsRegistrationUiUrl** | **String** | Configures the Ory Kratos Registration UI URL  This governs the \"selfservice.flows.registration.ui_url\" setting. | [optional] 
**kratosSelfserviceFlowsSettingsAfterDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Settings Default Return URL  This governs the \"selfservice.flows.settings.after.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsSettingsAfterPasswordDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Settings Default Return URL After Updating Passwords  This governs the \"selfservice.flows.settings.after.password.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsSettingsAfterProfileDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Settings Default Return URL After Updating Profiles  This governs the \"selfservice.flows.settings.after.profile.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsSettingsLifespan** | **String** | Configures the Ory Kratos Settings Lifespan  This governs the \"selfservice.flows.settings.lifespan\" setting. | [optional] 
**kratosSelfserviceFlowsSettingsPrivilegedSessionMaxAge** | **String** | Configures the Ory Kratos Settings Privileged Session Max Age  This governs the \"selfservice.flows.settings.privileged_session_max_age\" setting. | [optional] 
**kratosSelfserviceFlowsSettingsRequiredAal** | **String** | Configures the Ory Kratos Settings Required AAL  This governs the \"selfservice.flows.settings.required_aal\" setting. | [optional] 
**kratosSelfserviceFlowsSettingsUiUrl** | **String** | Configures the Ory Kratos Settings UI URL  This governs the \"selfservice.flows.settings.ui_url\" setting. | [optional] 
**kratosSelfserviceFlowsVerificationAfterDefaultBrowserReturnUrl** | **String** | Configures the Ory Kratos Verification Default Return URL  This governs the \"selfservice.flows.verification.after.default_browser_return_url\" setting. | [optional] 
**kratosSelfserviceFlowsVerificationEnabled** | **bool** | Configures the Ory Kratos Verification Enabled Setting  This governs the \"selfservice.flows.verification.enabled\" setting. | [optional] 
**kratosSelfserviceFlowsVerificationLifespan** | **String** | Configures the Ory Kratos Verification Lifespan  This governs the \"selfservice.flows.verification.lifespan\" setting. | [optional] 
**kratosSelfserviceFlowsVerificationUiUrl** | **String** | Configures the Ory Kratos Verification UI URL  This governs the \"selfservice.flows.verification.ui_url\" setting. | [optional] 
**kratosSelfserviceMethodsLinkConfigBaseUrl** | **String** | Configures the Base URL which Recovery, Verification, and Login Links Point to  It is recommended to leave this value empty. It will be appropriately configured to the best matching domain (e.g. when using custom domains) automatically.  This governs the \"selfservice.methods.link.config.base_url\" setting. | [optional] 
**kratosSelfserviceMethodsLinkConfigLifespan** | **String** | Configures whether Ory Kratos Link Method is enabled  This governs the \"selfservice.methods.link.config.lifespan\" setting. | [optional] 
**kratosSelfserviceMethodsLinkEnabled** | **bool** |  | [optional] 
**kratosSelfserviceMethodsLookupSecretEnabled** | **bool** |  | [optional] 
**kratosSelfserviceMethodsOidcConfigBaseRedirectUri** | **String** | Configures the Ory Kratos Third Party / OpenID Connect base redirect URI  This governs the \"selfservice.methods.oidc.config.base_redirect_uri\" setting. | [optional] 
**kratosSelfserviceMethodsOidcConfigProviders** | [**List<NormalizedProjectRevisionThirdPartyProvider>**](NormalizedProjectRevisionThirdPartyProvider.md) |  | [optional] [default to const []]
**kratosSelfserviceMethodsOidcEnabled** | **bool** | Configures whether Ory Kratos Third Party / OpenID Connect Login is enabled  This governs the \"selfservice.methods.oidc.enabled\" setting. | [optional] 
**kratosSelfserviceMethodsPasswordConfigHaveibeenpwnedEnabled** | **bool** |  | [optional] 
**kratosSelfserviceMethodsPasswordConfigIdentifierSimilarityCheckEnabled** | **bool** |  | [optional] 
**kratosSelfserviceMethodsPasswordConfigIgnoreNetworkErrors** | **bool** |  | [optional] 
**kratosSelfserviceMethodsPasswordConfigMaxBreaches** | **int** | Configures Ory Kratos Password Max Breaches Detection  This governs the \"selfservice.methods.password.config.max_breaches\" setting. | [optional] 
**kratosSelfserviceMethodsPasswordConfigMinPasswordLength** | **int** | Configures the minimum length of passwords.  This governs the \"selfservice.methods.password.config.min_password_length\" setting. | [optional] 
**kratosSelfserviceMethodsPasswordEnabled** | **bool** |  | [optional] 
**kratosSelfserviceMethodsProfileEnabled** | **bool** |  | [optional] 
**kratosSelfserviceMethodsTotpConfigIssuer** | **String** | Configures Ory Kratos TOTP Issuer  This governs the \"selfservice.methods.totp.config.issuer\" setting. | [optional] 
**kratosSelfserviceMethodsTotpEnabled** | **bool** |  | [optional] 
**kratosSelfserviceMethodsWebauthnConfigPasswordless** | **bool** | Configures whether Ory Kratos Webauthn is used for passwordless flows  This governs the \"selfservice.methods.webauthn.config.passwordless\" setting. | [optional] 
**kratosSelfserviceMethodsWebauthnConfigRpDisplayName** | **String** | Configures the Ory Kratos Webauthn RP Display Name  This governs the \"selfservice.methods.webauthn.config.rp.display_name\" setting. | [optional] 
**kratosSelfserviceMethodsWebauthnConfigRpIcon** | **String** | Configures the Ory Kratos Webauthn RP Icon  This governs the \"selfservice.methods.webauthn.config.rp.icon\" setting. | [optional] 
**kratosSelfserviceMethodsWebauthnConfigRpId** | **String** | Configures the Ory Kratos Webauthn RP ID  This governs the \"selfservice.methods.webauthn.config.rp.id\" setting. | [optional] 
**kratosSelfserviceMethodsWebauthnConfigRpOrigin** | **String** | Configures the Ory Kratos Webauthn RP Origin  This governs the \"selfservice.methods.webauthn.config.rp.origin\" setting. | [optional] 
**kratosSelfserviceMethodsWebauthnEnabled** | **bool** |  | [optional] 
**kratosSessionCookiePersistent** | **bool** |  | [optional] 
**kratosSessionCookieSameSite** | **String** | Configures the Ory Kratos Session Cookie SameSite Attribute  This governs the \"session.cookie.same_site\" setting. | [optional] 
**kratosSessionLifespan** | **String** | Configures the Ory Kratos Session Lifespan  This governs the \"session.lifespan\" setting. | [optional] 
**kratosSessionWhoamiRequiredAal** | **String** | Configures the Ory Kratos Session Whoami AAL requirement  This governs the \"session.whoami.required_aal\" setting. | [optional] 
**name** | **String** | The project's name. | 
**production** | **bool** | Whether this project is in production mode or not.  In development mode, a low-security profile is used making it easier to develop against your, for example, local environment. | [optional] 
**projectId** | **String** |  | [optional] 
**updatedAt** | [**DateTime**](DateTime.md) | Last Time Project's Revision was Updated | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


